@@ -1,19 +1,20 @@
 from __future__ import unicode_literals, division, absolute_import
 from datetime import datetime, timedelta
 from string import capwords
+from flexget.event import event
+
 from flexget.manager import Session
 from flexget.plugin import register_plugin, register_parser_option, DependencyError
 from flexget.utils.tools import console
 
 try:
-    from flexget.plugins.filter.series import (SeriesDatabase, Series, Episode, Release,
-                                               forget_series, forget_series_episode)
+    from flexget.plugins.filter.series import (SeriesDatabase, Series, Episode, Release, SeriesTask,
+                                               forget_series, forget_series_episode, set_series_begin)
 except ImportError:
     raise DependencyError(issued_by='cli_series', missing='series', message='Series commandline interface not loaded')
 
 
 class SeriesReport(SeriesDatabase):
-
     """Produces --series report"""
 
     def on_process_start(self, task):
@@ -88,14 +89,19 @@ class SeriesReport(SeriesDatabase):
         result = {}
         session = Session()
         try:
-            for series in session.query(Series).all():
+            seriestasks = session.query(SeriesTask).all()
+            if seriestasks:
+                all_series = set(st.series for st in seriestasks)
+            else:
+                all_series = session.query(Series).all()
+            for series in all_series:
                 name = series.name
                 # capitalize if user hasn't, better look and sorting ...
                 if name.islower():
                     name = capwords(name)
                 result[name] = {'identified_by': series.identified_by}
+                result[name]['in_tasks'] = [task.name for task in series.in_tasks]
                 episode = self.get_latest_download(series)
-
                 if episode:
                     latest = {'first_seen': episode.first_seen,
                               'episode_instance': episode,
@@ -153,7 +159,7 @@ class SeriesReport(SeriesDatabase):
                 if last_dl['first_seen'] < datetime.now() - timedelta(days=30 * 7) and behind <= 3:
                     hidden += 1
                     continue
-            else:
+            elif not data.get('in_tasks'):
                 # no recorded downloads
                 hidden += 1
                 continue
@@ -176,7 +182,6 @@ class SeriesReport(SeriesDatabase):
 
 
 class SeriesForget(object):
-
     """Provides --series-forget"""
 
     def on_process_start(self, task):
@@ -205,9 +210,33 @@ class SeriesForget(object):
             task.manager.config_changed()
 
 
+@event('manager.startup')
+def series_begin(manager):
+    if not manager.options.series_begin:
+        return
+    manager.disable_tasks()
+    series_name, ep_id = manager.options.series_begin
+    session = Session()
+    series = session.query(Series).filter(Series.name == series_name).first()
+    if not series:
+        console('Unknown series `%s`' % series_name)
+        return
+    try:
+        set_series_begin(series, ep_id)
+    except ValueError as e:
+        console(e)
+    else:
+        console('Episodes for `%s` will be accepted starting with `%s`' % (series.name, ep_id))
+        session.commit()
+    finally:
+        session.close()
+
+
 register_plugin(SeriesReport, '--series', builtin=True)
 register_plugin(SeriesForget, '--series-forget', builtin=True)
 
+register_parser_option('--series-begin', nargs=2, metavar=('NAME', 'EP_ID'),
+                       help='Mark the first desired episode of a series. Episodes before this will not be grabbed')
 register_parser_option('--series', nargs='?', const=True, help='Display series summary.')
 register_parser_option('--series-forget', nargs='1-2', metavar=('NAME', 'EP_ID'),
                        help='Remove complete series or single episode from database: <NAME> [EPISODE]')
